@@ -67,9 +67,7 @@ class BaseClassificationDatabasePacker(object):
         for compression_option in [zipfile.ZIP_DEFLATED, zipfile.ZIP_STORED]:
             try:
                 params['compression'] = compression_option
-                return zipfile.ZipFile(
-                    file, **params
-                )
+                return zipfile.ZipFile(str(file), **params)
             except RuntimeError:
                 pass
 
@@ -192,10 +190,10 @@ class ClassificationDatabasePacker(BaseClassificationDatabasePacker):
 
             if not self.progress_bar:
                 for img in self.images:
-                    zip_io.write(img.filepath, pathlib.Path('images') / img.filename)
+                    zip_io.write(img.filepath, str(pathlib.Path('images') / img.filename))
             else:
                 for img in tqdm.tqdm(self.images):
-                    zip_io.write(img.filepath, pathlib.Path('images') / img.filename)
+                    zip_io.write(img.filepath, str(pathlib.Path('images') / img.filename))
 
         return self.destination
 
